==> limma_1.3.1.tar.gz: limma/man/readImageneHeaders.Rd <==
\name{readImageneHeaders}
\alias{readImageneHeaders}
\title{Read Imagene Header Information}
\description{
Read the header information from an Imagene image analysis output file.
This function is used internally by \code{read.maimages} and is not usually called directly by users.
}
\usage{
readImageneHeaders(file)
}
\arguments{
  \item{file}{character string giving file name, including path if not in current working directory}
}
\details{
Output files produced by the image analysis software Imagene include a number of lines of header which contain information about the printing process.
This function extracts that information and locates the line where the intensity data begins.
}
\value{
A list with components
  \item{Begin.Raw.Data}{line number immediately before intensity data begins}
  \item{Version}{version number of Imagene software}
  \item{Date}{character string giving time and data that array was scanned}
  \item{Image.File}{character string giving original file name to which data was written by Imagene}
  \item{Inverted}{logical}
  \item{Field.Dimension}{list with components \code{Field} containing a character string,
  \code{Metarows} containing number of grid rows,
  \code{Metacols} containing number of grid columns,
  \code{Rows} containing number of spot rows in each grid,
  \code{Cols} containing number of spot columns in each grid}
  \item{Measurement.Parameters}{list with numerical components \code{Signal.Low}, \code{Signal.High}, \code{Background.Low}, \code{Background.High}, \code{Background.Buffer} and \code{Background.Width}}
}
\references{
\url{http://www.biodiscovery.com/imagene.asp}
}
\author{Gordon Smyth}
\seealso{\code{\link{read.imagene}}

An overview of LIMMA functions to read data is given in \link{3.ReadingData}.
}
\examples{
\dontrun{This function is not intended to be called by users.
There is an example of use in the code for function read.imagene.}
print(read.imagene)
}
\keyword{file}

==> limma_1.6.7.tar.gz: limma/man/readImageneHeaders.Rd <==
\name{readImageneHeaders}
\alias{readImageneHeaders}
\title{Read Imagene Header Information}
\description{
Read the header information from an Imagene image analysis output file.
This function is used internally by \code{read.maimages} and is not usually called directly by users.
}
\usage{
readImageneHeaders(file)
}
\arguments{
  \item{file}{character string giving file name, including path if not in current working directory}
}
\details{
Output files produced by the image analysis software Imagene include a number of lines of header which contain information about the printing process.
This function extracts that information and locates the line where the intensity data begins.
}
\value{
A list with components
  \item{Begin.Raw.Data}{line number immediately before the line where the intensity data begins}
  \item{Version}{version number of Imagene software}
  \item{Date}{character string giving time and data that array was scanned}
  \item{Image.File}{character string giving original file name to which data was written by Imagene}
  \item{Inverted}{logical}
  \item{Field.Dimension}{list with components \code{Field} containing a character string,
  \code{Metarows} containing number of grid rows,
  \code{Metacols} containing number of grid columns,
  \code{Rows} containing number of spot rows in each grid,
  \code{Cols} containing number of spot columns in each grid}
  \item{Measurement.Parameters}{list with numerical components \code{Signal.Low}, \code{Signal.High}, \code{Background.Low}, \code{Background.High}, \code{Background.Buffer} and \code{Background.Width}}
}
\references{
\url{http://www.biodiscovery.com/imagene.asp}
}
\author{Gordon Smyth}
\seealso{\code{\link{read.imagene}}

An overview of LIMMA functions to read data is given in \link{3.ReadingData}.
}
\examples{
\dontrun{This function is not intended to be called by users.
There is an example of use in the code for function read.imagene.}
print(read.imagene)
}
\keyword{file}
